pygeodesy.deprecated.functions

Package pygeodesy :: Package deprecated :: Module functions |
[frames] | no frames]

# Module functions

DEPRECATED functions kept for backward compatibility.

Version: 26.02.12

Functions
anStr(name, OKd=`'``._-``'`, sub='_') DEPRECATED, use function pygeodesy.anstr. |
areaof(points, adjust=True, radius=6371008.771415, wrap=True) DEPRECATED, use function pygeodesy.areaOf. |
atand(x) DEPRECATED on 2023.09.28, use function pygeodesy.atan1d. |
bounds(points, wrap=True, LatLon=None) DEPRECATED, use function pygeodesy.boundsOf. |
clipCS3(points, lowerleft, upperright, closed=False, inull=False) DEPRECATED, use function pygeodesy.clipCS4. |
clipDMS(deg, limit) DEPRECATED, use function pygeodesy.clipDegrees. |
clipStr(bstr, limit=50, white='') DEPRECATED, use function pygeodesy.clips. |
collins(pointA, pointB, pointC, alpha, beta, **useZ_Clas_and_kwds) DEPRECATED, use function pygeodesy.collins5. |
copysign(x, y) DEPRECATED, use function pygeodesy.copysign0. |
cosineAndoyerLambert(lat1, lon1, lat2, lon2, **datum_wrap) DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw with `corr=1`. |
cosineAndoyerLambert_(phi2, phi1, lam21, **datum) DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw_ with `corr=1`. |
cosineForsytheAndoyerLambert(lat1, lon1, lat2, lon2, **datum_wrap) DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw with `corr=2`. |
cosineForsytheAndoyerLambert_(phi2, phi1, lam21, **datum) DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw_ with `corr=2`. |
decodeEPSG2(arg) DEPRECATED, use function epsg.decode2. |
elliperim(a, b, *deg2_1) DEPRECATED on 2026.02.12, use method pygeodesy.Ellipse.arc or property pygeodesy.Ellipse.perimeter2k_. |
elliperim_(a, b, *rad2_1) DEPRECATED on 2026.02.12, use method pygeodesy.Ellipse.arc_ or property pygeodesy.Ellipse.perimeter2k_. |
encodeEPSG(zone, hemipole='', band='') DEPRECATED, use function epsg.encode. |
enStr2(easting, northing, prec, *extras) DEPRECATED, use function pygeodesy.enstr2. |
equirectangular_(lat1, lon1, lat2, lon2, **options) DEPRECATED on 2024.05.25, use function pygeodesy.equirectangular4. |
equirectangular3(lat1, lon1, lat2, lon2, **options) DEPRECATED, use function pygeodesy.equirectangular4. |
excessAbc(A, b, c) DEPRECATED on 2023.04.04, use function pygeodesy.excessAbc_. |
excessGirard(A, B, C) DEPRECATED on 2023.04.04, use function pygeodesy.excessGirard_. |
excessLHuilier(a, b, c) DEPRECATED on 2023.04.04, use function pygeodesy.excessLHuilier_. |
false2f(value, name=`'``value``'`, false=True, Error=<type 'exceptions.ValueError'>) DEPRECATED, use class Easting or Northing. |
falsed2f(falsed=True, Error=<type 'exceptions.ValueError'>, **name_value) DEPRECATED, use class Easting or Northing. |
float0(*xs) DEPRECATED on 2023.04.21, use function pygeodesy.float0_. |
fStr(floats, prec=6, fmt='f', ints=False, sep=', ') DEPRECATED, use function fstr. |
fStrzs(floatstr) DEPRECATED, use function pygeodesy.fstrzs. |
Fsum2product(*xs, **kwds) DEPRECATED on 2024.09.19, use Fsum`(*xs, f2product=True, ...)`. |
hypot3(x, y, z) DEPRECATED, use function pygeodesy.hypot_. |
inStr(inst, *args, **kwds) DEPRECATED, use function pygeodesy.instr. |
isenclosedby(point, points, wrap=False) DEPRECATED, use function pygeodesy.isenclosedBy. |
istuplist(obj, minum=0) DEPRECATED on 2023.03.31, use function pygeodesy.islistuple. |
joined(*words, **sep) DEPRECATED, use `NN(...)`, `NN.join_` or `sep.join`. |
joined_(*words, **sep) DEPRECATED, use `_SPACE_(...)`, `_SPACE_.join_` or `sep.join`, sep=" ". |
nearestOn3(point, points, closed=False, wrap=False, **options) DEPRECATED, use function pygeodesy.nearestOn5. |
nearestOn4(point, points, closed=False, wrap=False, **options) DEPRECATED, use function pygeodesy.nearestOn5. |
parseUTM(strUTM, datum=_UTM, Utm=_UTM, name='') DEPRECATED, use function parseUTM5. |
perimeterof(points, closed=False, adjust=True, radius=6371008.771415, wrap=True) DEPRECATED, use function pygeodesy.perimeterOf. |
polygon(points, closed=True, base=None) DEPRECATED, use function pygeodesy.points2. |
scalar(value, low=2.220446049250313e-16, high=1.0, name=`'``scalar``'`, Error=<type 'exceptions.ValueError'>) DEPRECATED, use class Number_ or Scalar_. |
simplify2(points, pipe=0.001, **radius_shortest_indices_options) DEPRECATED, use function pygeodesy.simplifyRW. |
simplifyRDPm(points, distance=0.001, **radius_shortest_indices_options) DEPRECATED on 2024.11.28, use function pygeodesy.simplifyRDP`(points, modified=True, ...)`. |
simplifyVWm(points, area=0.001, **radius_attr_indices_options) DEPRECATED on 2024.11.28, use function pygeodesy.simplifyVW`(points, modified=True, ...)`. |
tienstra(pointA, pointB, pointC, alpha, **beta_gamma_useZ_Clas_and_kwds) DEPRECATED, use function pygeodesy.tienstra7. |
toUtm(latlon, lon=None, datum=None, Utm=_UTM, cmoff=True, name='') DEPRECATED, use function pygeodesy.toUtm8. |
triAngle4(a, b, c) DEPRECATED on 2023.09.14, use function pygeodesy.triAngle5. |
unsign0(x) DEPRECATED, use function pygeodesy.unsigned0. |
unStr(name, *args, **kwds) DEPRECATED, use function pygeodesy.unstr. |
utmZoneBand2(lat, lon) DEPRECATED, use function pygeodesy.utmZoneBand5. |

Variables
| __all__ = `_ALL_DEPRECATED.deprecated_functions`

Function Details

### anStr (name, OKd=`'``._-``'`, sub='_') |
DEPRECATED, use function pygeodesy.anstr. Decorators: `@deprecated_function`

### areaof (points, adjust=True, radius=6371008.771415, wrap=True) |
DEPRECATED, use function pygeodesy.areaOf. Decorators: `@deprecated_function`

### atand (x) |
DEPRECATED on 2023.09.28, use function pygeodesy.atan1d. Decorators: `@deprecated_function`

### bounds (points, wrap=True, LatLon=None) |
DEPRECATED, use function pygeodesy.boundsOf. Returns: 2-Tuple `(latlonSW, latlonNE)`, each a `LatLon` or 4-Tuple `(latS, lonW, latN, lonE)` if `LatLon is None`. Decorators: `@deprecated_function`

### clipCS3 (points, lowerleft, upperright, closed=False, inull=False) |
DEPRECATED, use function pygeodesy.clipCS4. Returns: Yield a ClipCS3Tuple`(start, end, index)` for each edge of the clipped path. Decorators: `@deprecated_function`

### clipDMS (deg, limit) |
DEPRECATED, use function pygeodesy.clipDegrees. Decorators: `@deprecated_function`

### clipStr (bstr, limit=50, white='') |
DEPRECATED, use function pygeodesy.clips. Decorators: `@deprecated_function`

### collins (pointA, pointB, pointC, alpha, beta, **useZ_Clas_and_kwds) |
DEPRECATED, use function pygeodesy.collins5. Decorators: `@deprecated_function`

### copysign (x, y) |
DEPRECATED, use function pygeodesy.copysign0. Decorators: `@deprecated_function`

### cosineAndoyerLambert (lat1, lon1, lat2, lon2, **datum_wrap) |
DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw with `corr=1`. Decorators: `@deprecated_function`

### cosineAndoyerLambert_ (phi2, phi1, lam21, **datum) |
DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw_ with `corr=1`. Decorators: `@deprecated_function`

### cosineForsytheAndoyerLambert (lat1, lon1, lat2, lon2, **datum_wrap) |
DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw with `corr=2`. Decorators: `@deprecated_function`

### cosineForsytheAndoyerLambert_ (phi2, phi1, lam21, **datum) |
DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw_ with `corr=2`. Decorators: `@deprecated_function`

### decodeEPSG2 (arg) |
DEPRECATED, use function epsg.decode2. Returns: 2-Tuple `(zone, hemipole)` Decorators: `@deprecated_function`

### elliperim (a, b, *deg2_1) |
DEPRECATED on 2026.02.12, use method pygeodesy.Ellipse.arc or property pygeodesy.Ellipse.perimeter2k_. Decorators: `@deprecated_function`

### elliperim_ (a, b, *rad2_1) |
DEPRECATED on 2026.02.12, use method pygeodesy.Ellipse.arc_ or property pygeodesy.Ellipse.perimeter2k_. Decorators: `@deprecated_function`

### encodeEPSG (zone, hemipole='', band='') |
DEPRECATED, use function epsg.encode. Returns: `EPSG` code (`int`). Decorators: `@deprecated_function`

### enStr2 (easting, northing, prec, *extras) |
DEPRECATED, use function pygeodesy.enstr2. Decorators: `@deprecated_function`

### equirectangular_ (lat1, lon1, lat2, lon2, **options) |
DEPRECATED on 2024.05.25, use function pygeodesy.equirectangular4. Decorators: `@deprecated_function`

### equirectangular3 (lat1, lon1, lat2, lon2, **options) |
DEPRECATED, use function pygeodesy.equirectangular4. Returns: 3-Tuple `(distance2, delta_lat, delta_lon)`. Decorators: `@deprecated_function`

### excessAbc (A, b, c) |
DEPRECATED on 2023.04.04, use function pygeodesy.excessAbc_. Decorators: `@deprecated_function`

### excessGirard (A, B, C) |
DEPRECATED on 2023.04.04, use function pygeodesy.excessGirard_. Decorators: `@deprecated_function`

### excessLHuilier (a, b, c) |
DEPRECATED on 2023.04.04, use function pygeodesy.excessLHuilier_. Decorators: `@deprecated_function`

### false2f (value, name=`'``value``'`, false=True, Error=<type 'exceptions.ValueError'>) |
DEPRECATED, use class Easting or Northing. Decorators: `@deprecated_function`

### falsed2f (falsed=True, Error=<type 'exceptions.ValueError'>, **name_value) |
DEPRECATED, use class Easting or Northing. Convert a falsed east-/northing to non-negative `float`. Arguments: `falsed` - Value includes false origin (`bool`). `Error` - Optional, overriding error (`Exception`). `name_value` - One `name=value` pair. Returns: The value (`float`). Decorators: `@deprecated_function` Raises: `Error` - Invalid or negative `name=value`.

### float0 (*xs) |
DEPRECATED on 2023.04.21, use function pygeodesy.float0_. Decorators: `@deprecated_function`

### fStr (floats, prec=6, fmt='f', ints=False, sep=', ') |
DEPRECATED, use function fstr. Decorators: `@deprecated_function`

### fStrzs (floatstr) |
DEPRECATED, use function pygeodesy.fstrzs. Decorators: `@deprecated_function`

### Fsum2product (*xs, **kwds) |
DEPRECATED on 2024.09.19, use Fsum`(*xs, f2product=True, ...)`. Decorators: `@deprecated_function`

### hypot3 (x, y, z) |
DEPRECATED, use function pygeodesy.hypot_. Decorators: `@deprecated_function`

### inStr (inst, *args, **kwds) |
DEPRECATED, use function pygeodesy.instr. Decorators: `@deprecated_function`

### isenclosedby (point, points, wrap=False) |
DEPRECATED, use function pygeodesy.isenclosedBy. Decorators: `@deprecated_function`

### istuplist (obj, minum=0) |
DEPRECATED on 2023.03.31, use function pygeodesy.islistuple. Decorators: `@deprecated_function`

### joined (*words, **sep) |
DEPRECATED, use `NN(...)`, `NN.join_` or `sep.join`. Decorators: `@deprecated_function`

### joined_ (*words, **sep) |
DEPRECATED, use `_SPACE_(...)`, `_SPACE_.join_` or `sep.join`, sep=" ". Decorators: `@deprecated_function`

### nearestOn3 (point, points, closed=False, wrap=False, **options) |
DEPRECATED, use function pygeodesy.nearestOn5. Returns: 3-Tuple `(lat, lon, distance)` Decorators: `@deprecated_function`

### nearestOn4 (point, points, closed=False, wrap=False, **options) |
DEPRECATED, use function pygeodesy.nearestOn5. Returns: 4-Tuple `(lat, lon, distance, angle)` Decorators: `@deprecated_function`

### parseUTM (strUTM, datum=_UTM, Utm=_UTM, name='') |
DEPRECATED, use function parseUTM5. Returns: The UTM coordinate (Utm) or 4-tuple `(zone, hemisphere, easting, northing)` if `Utm is None`. Decorators: `@deprecated_function`

### perimeterof (points, closed=False, adjust=True, radius=6371008.771415, wrap=True) |
DEPRECATED, use function pygeodesy.perimeterOf. Decorators: `@deprecated_function`

### polygon (points, closed=True, base=None) |
DEPRECATED, use function pygeodesy.points2. Decorators: `@deprecated_function`

### scalar (value, low=2.220446049250313e-16, high=1.0, name=`'``scalar``'`, Error=<type 'exceptions.ValueError'>) |
DEPRECATED, use class Number_ or Scalar_. Returns: New value (`float` or `int` for `int` `low`). Decorators: `@deprecated_function` Raises: `Error` - Invalid `value`.

### simplify2 (points, pipe=0.001, **radius_shortest_indices_options) |
DEPRECATED, use function pygeodesy.simplifyRW. Decorators: `@deprecated_function`

### simplifyRDPm (points, distance=0.001, **radius_shortest_indices_options) |
DEPRECATED on 2024.11.28, use function pygeodesy.simplifyRDP`(points, modified=True, ...)`. Decorators: `@deprecated_function`

### simplifyVWm (points, area=0.001, **radius_attr_indices_options) |
DEPRECATED on 2024.11.28, use function pygeodesy.simplifyVW`(points, modified=True, ...)`. Decorators: `@deprecated_function`

### tienstra (pointA, pointB, pointC, alpha, **beta_gamma_useZ_Clas_and_kwds) |
DEPRECATED, use function pygeodesy.tienstra7. Decorators: `@deprecated_function`

### toUtm (latlon, lon=None, datum=None, Utm=_UTM, cmoff=True, name='') |
DEPRECATED, use function pygeodesy.toUtm8. Returns: The UTM coordinate (`Utm`) or a 6-tuple `(zone, easting, northing, band, convergence, scale)` if `Utm is None` or `cmoff is False`. Decorators: `@deprecated_function`

### triAngle4 (a, b, c) |
DEPRECATED on 2023.09.14, use function pygeodesy.triAngle5. Returns: A DEPRECATED TriAngle4Tuple`(radA, radB, radC, rIn)`. Decorators: `@deprecated_function`

### unsign0 (x) |
DEPRECATED, use function pygeodesy.unsigned0. Decorators: `@deprecated_function`

### unStr (name, *args, **kwds) |
DEPRECATED, use function pygeodesy.unstr. Decorators: `@deprecated_function`

### utmZoneBand2 (lat, lon) |
DEPRECATED, use function pygeodesy.utmZoneBand5. Returns: 2-Tuple `(zone, band)`. Decorators: `@deprecated_function`